@@ -41,6 +41,13 @@ def is_external(url):
     prefixes = ("http", "www", "mailto:", "tel:", "skype:", "ftp:")
     return url.startswith(prefixes)
 
+def is_base64_image(url):
+    """
+    Test if a url is a base64 data image.
+    """
+    prefixes = ("data:image")
+    return url.startswith(prefixes)
+
 
 def is_attachment(url):
     """
@@ -201,9 +208,9 @@ def fix_image_src(page_html, page_url, directory_urls):
     This is because flattening all pages into 1 print page will break any relative links.
     """
     # Loop over all images src attributes
-    # Example regex https://regex101.com/r/TTRsVW/1
+    # Example regex https://regex101.com/r/PLUmZ7/2
     img_regex = re.compile(
-        r"\<img.+src=\"([aA-zZ|0-9|\-|\_|\.|\:|\/]+)\"", flags=re.IGNORECASE
+        r"<img[^>]+src=\"([^\">]+)\"", flags=re.IGNORECASE
     )
     matches = re.finditer(img_regex, page_html)
 
@@ -211,6 +218,9 @@ def fix_image_src(page_html, page_url, directory_urls):
         img_src = m.group(1)
         if is_external(img_src):
             continue
+        elif is_base64_image(img_src):
+            continue
+        
         img_text = m.group()
 
         new_url = get_url_from_root(img_src, page_url)
